local addon, private = ...
local mod = LibStub("AceAddon-3.0"):GetAddon(addon)

-- TODO: Localize
mod.SLOT_GROUPS = {
  {
    { name = "Head", slot_id = 1},
    { name = "Neck", slot_id = 2},
    { name = "Shoulder", slot_id = 3},
    { name = "Cloak", slot_id = 15},
    { name = "Chest", slot_id = 5},
    { name = "Shirt", slot_id = 4},
    { name = "Tabard", slot_id = 19},
    { name = "Wrist", slot_id = 9}
  },
  {
    { name = "Hands", slot_id = 10},
    { name = "Waist", slot_id = 6},
    { name = "Legs", slot_id = 7},
    { name = "Feet", slot_id = 8},
    { name = "Ring 1", slot_id = 11},
    { name = "Ring 2", slot_id = 12},
    { name = "Trinket 1", slot_id = 13},
    { name = "Trinket 2", slot_id = 14}
  },
  {
    { name = "Main Hand", slot_id = 16},
    { name = "Off Hand", slot_id = 17},
    { name = "Relic 1", slot_id = getSocketSlotID(), artifact_gem_id = 1},
    { name = "Relic 2", slot_id = getSocketSlotID(), artifact_gem_id = 2},
    { name = "Relic 2", slot_id = getSocketSlotID(), artifact_gem_id = 3}
  }
}

mod.SIMC_SLOT_NAMES = {
  INVTYPE_HEAD = 'head',
  INVTYPE_NECK = 'neck',
  INVTYPE_SHOULDER = 'shoulder',
  INVTYPE_CLOAK = 'back',
  INVTYPE_CHEST = 'chest',
  INVTYPE_ROBE = 'chest',
  INVTYPE_BODY = 'shirt',
  INVTYPE_TABARD = 'tabard',
  INVTYPE_WRIST = 'wrist',
  INVTYPE_HAND = 'hands',
  INVTYPE_WAIST = 'waist',
  INVTYPE_LEGS = 'legs',
  INVTYPE_FEET = 'feet',
  INVTYPE_FINGER = 'finger1',
  INVTYPE_TRINKET = 'trinket1',
  INVTYPE_2HWEAPON = 'main_hand',
  INVTYPE_HOLDABLE = 'off_hand',
  INVTYPE_SHIELD = 'off_hand',
  INVTYPE_RANGED = 'main_hand',
  INVTYPE_WEAPONMAINHAND = 'main_hand',
  INVTYPE_WEAPONOFFHAND = 'off_hand',
  INVTYPE_AMMO = 'ammo'
}

-- Copied from SimC
mod.UPGRADE_TABLE = {
  [0]   =  0,
  [1]   =  1, -- 1/1 -> 8
  [373] =  1, -- 1/2 -> 4
  [374] =  2, -- 2/2 -> 8
  [375] =  1, -- 1/3 -> 4
  [376] =  2, -- 2/3 -> 4
  [377] =  3, -- 3/3 -> 4
  [378] =  1, -- 1/1 -> 7
  [379] =  1, -- 1/2 -> 4
  [380] =  2, -- 2/2 -> 4
  [445] =  0, -- 0/2 -> 0
  [446] =  1, -- 1/2 -> 4
  [447] =  2, -- 2/2 -> 8
  [451] =  0, -- 0/1 -> 0
  [452] =  1, -- 1/1 -> 8
  [453] =  0, -- 0/2 -> 0
  [454] =  1, -- 1/2 -> 4
  [455] =  2, -- 2/2 -> 8
  [456] =  0, -- 0/1 -> 0
  [457] =  1, -- 1/1 -> 8
  [458] =  0, -- 0/4 -> 0
  [459] =  1, -- 1/4 -> 4
  [460] =  2, -- 2/4 -> 8
  [461] =  3, -- 3/4 -> 12
  [462] =  4, -- 4/4 -> 16
  [465] =  0, -- 0/2 -> 0
  [466] =  1, -- 1/2 -> 4
  [467] =  2, -- 2/2 -> 8
  [468] =  0, -- 0/4 -> 0
  [469] =  1, -- 1/4 -> 4
  [470] =  2, -- 2/4 -> 8
  [471] =  3, -- 3/4 -> 12
  [472] =  4, -- 4/4 -> 16
  [476] =  0, -- ? -> 0
  [479] =  0, -- ? -> 0
  [491] =  0, -- ? -> 0
  [492] =  1, -- ? -> 0
  [493] =  2, -- ? -> 0
  [494] = 0,
  [495] = 1,
  [496] = 2,
  [497] = 3,
  [498] = 4,
  [504] = 3,
  [505] = 4,
  -- WOW-20726patch6.2.3_Retail
  [529] = 0, -- 0/2 -> 0
  [530] = 1, -- 1/2 -> 5
  [531] = 2 -- 2/2 -> 10
}

mod.OFFSETS = {
  ITEM_ID = 1,
  ENCHANT_ID = 2,
  GEM_ID_1 = 3,
  GEM_ID_2 = 4,
  GEM_ID_3 = 5,
  GEM_ID_4 = 6,
  SUFFIX_ID = 7,
  FLAGS = 11,
  BONUS_ID = 13,
  UPGRADE_ID = 14 -- Flags = 0x4
}

mod.ARTIFACT_TABLE = {
  -- Death Knight
  [128402] = 15,
  [128292] = 12,
  [128403] = 16,
  -- Demon Hunter
  [127829] = 3,
  [128832] = 60,
  -- Druid
  [128858] = 59,
  [128860] = 58,
  [128821] = 57,
  [128306] = 13,
  -- Hunter
  [128861] = 56,
  [128826] = 55,
  [128808] = 34,
  -- Mage
  [127857] = 4,
  [128820] = 54,
  [128862] = 53,
  -- Monk
  [128938] = 52,
  [128937] = 51,
  [128940] = 50,
  -- Paladin
  [128823] = 48,
  [128866] = 49,
  [120978] = 2,
  -- Priest
  [128868] = 46,
  [128825] = 45,
  [128827] = 47,
  -- Rogue
  [128870] = 43,
  [128872] = 44,
  [128476] = 17,
  -- Shaman
  [128935] = 40,
  [128819] = 41,
  [128911] = 32,
  -- Warlock
  [128942] = 39,
  [128943] = 37,
  [128941] = 38,
  -- Warrior
  [128910] = 36,
  [128908] = 35,
  [128289] = 11
}